import { FastDomNode } from 'vs/base/browser/fastDomNode';
import { IMouseEvent, StandardWheelEvent } from 'vs/base/browser/mouseEvent';
import { ScrollbarArrowOptions } from 'vs/base/browser/ui/scrollbar/scrollbarArrow';
import { ScrollbarState } from 'vs/base/browser/ui/scrollbar/scrollbarState';
import { ScrollbarVisibilityController } from 'vs/base/browser/ui/scrollbar/scrollbarVisibilityController';
import { Widget } from 'vs/base/browser/ui/widget';
import { INewScrollPosition, Scrollable, ScrollbarVisibility } from 'vs/base/common/scrollable';
export interface ISimplifiedMouseEvent {
    buttons: number;
    posx: number;
    posy: number;
}
export interface ScrollbarHost {
    onMouseWheel(mouseWheelEvent: StandardWheelEvent): void;
    onDragStart(): void;
    onDragEnd(): void;
}
export interface AbstractScrollbarOptions {
    lazyRender: boolean;
    host: ScrollbarHost;
    scrollbarState: ScrollbarState;
    visibility: ScrollbarVisibility;
    extraScrollbarClassName: string;
    scrollable: Scrollable;
    scrollByPage: boolean;
}
export declare abstract class AbstractScrollbar extends Widget {
    protected _host: ScrollbarHost;
    protected _scrollable: Scrollable;
    protected _scrollByPage: boolean;
    private _lazyRender;
    protected _scrollbarState: ScrollbarState;
    protected _visibilityController: ScrollbarVisibilityController;
    private _mouseMoveMonitor;
    domNode: FastDomNode<HTMLElement>;
    slider: FastDomNode<HTMLElement>;
    protected _shouldRender: boolean;
    constructor(opts: AbstractScrollbarOptions);
    /**
     * Creates the dom node for an arrow & adds it to the container
     */
    protected _createArrow(opts: ScrollbarArrowOptions): void;
    /**
     * Creates the slider dom node, adds it to the container & hooks up the events
     */
    protected _createSlider(top: number, left: number, width: number | undefined, height: number | undefined): void;
    protected _onElementSize(visibleSize: number): boolean;
    protected _onElementScrollSize(elementScrollSize: number): boolean;
    protected _onElementScrollPosition(elementScrollPosition: number): boolean;
    beginReveal(): void;
    beginHide(): void;
    render(): void;
    private _domNodeMouseDown;
    delegateMouseDown(e: IMouseEvent): void;
    private _onMouseDown;
    private _sliderMouseDown;
    private _setDesiredScrollPositionNow;
    updateScrollbarSize(scrollbarSize: number): void;
    isNeeded(): boolean;
    protected abstract _renderDomNode(largeSize: number, smallSize: number): void;
    protected abstract _updateSlider(sliderSize: number, sliderPosition: number): void;
    protected abstract _mouseDownRelativePosition(offsetX: number, offsetY: number): number;
    protected abstract _sliderMousePosition(e: ISimplifiedMouseEvent): number;
    protected abstract _sliderOrthogonalMousePosition(e: ISimplifiedMouseEvent): number;
    protected abstract _updateScrollbarSize(size: number): void;
    abstract writeScrollPosition(target: INewScrollPosition, scrollPosition: number): void;
}
