import { Emitter, Event } from 'vs/base/common/event';
import { Disposable, IDisposable } from 'vs/base/common/lifecycle';
export interface ITelemetryData {
    readonly from?: string;
    readonly target?: string;
    [key: string]: unknown;
}
export declare type WorkbenchActionExecutedClassification = {
    id: {
        classification: 'SystemMetaData';
        purpose: 'FeatureInsight';
    };
    from: {
        classification: 'SystemMetaData';
        purpose: 'FeatureInsight';
    };
};
export declare type WorkbenchActionExecutedEvent = {
    id: string;
    from: string;
};
export interface IAction extends IDisposable {
    readonly id: number;
    label: string;
    tooltip: string;
    class: string | undefined;
    enabled: boolean;
    checked?: boolean;
    type: string;
    accelerator: string | undefined;
    run(event?: unknown): unknown;
}
export interface IActionRunner extends IDisposable {
    readonly onDidRun: Event<IRunEvent>;
    readonly onBeforeRun: Event<IRunEvent>;
    run(action: IAction, context?: unknown): unknown;
}
export interface IActionChangeEvent {
    readonly label?: string;
    readonly tooltip?: string;
    readonly class?: string;
    readonly enabled?: boolean;
    readonly checked?: boolean;
}
export declare class Action extends Disposable implements IAction {
    protected _onDidChange: Emitter<IActionChangeEvent>;
    readonly onDidChange: Event<IActionChangeEvent>;
    protected readonly _id: number;
    protected _label: string;
    protected _tooltip: string | undefined;
    protected _cssClass: string | undefined;
    protected _enabled: boolean;
    protected _checked?: boolean;
    protected _type: string;
    protected _accelerator?: string;
    constructor(id: number, label?: string, cssClass?: string, enabled?: boolean, type?: string, accelerator?: string);
    get id(): number;
    get type(): string;
    get accelerator(): string | undefined;
    get label(): string;
    set label(value: string);
    private _setLabel;
    get tooltip(): string;
    set tooltip(value: string);
    protected _setTooltip(value: string): void;
    get class(): string | undefined;
    set class(value: string | undefined);
    protected _setClass(value: string | undefined): void;
    get enabled(): boolean;
    set enabled(value: boolean);
    protected _setEnabled(value: boolean): void;
    get checked(): boolean | undefined;
    set checked(value: boolean | undefined);
    protected _setChecked(value: boolean | undefined): void;
    run(event?: Function, data?: ITelemetryData): Promise<void>;
}
export interface IRunEvent {
    readonly action: IAction;
    readonly error?: Error;
}
export declare class ActionRunner extends Disposable implements IActionRunner {
    private _onBeforeRun;
    readonly onBeforeRun: Event<IRunEvent>;
    private _onDidRun;
    readonly onDidRun: Event<IRunEvent>;
    run(action: IAction, context?: unknown): Promise<void>;
    protected runAction(action: IAction, context?: unknown): Promise<void>;
}
export declare class Separator extends Action {
    /**
     * Joins all non-empty lists of actions with separators.
     */
    static join(...actionLists: readonly IAction[][]): IAction[];
    static readonly ID = -200;
    constructor(label?: string);
}
export declare class SubmenuAction implements IAction {
    readonly id: number;
    readonly label: string;
    readonly class: string | undefined;
    readonly tooltip: string;
    readonly enabled: boolean;
    readonly checked: undefined;
    readonly type: string;
    readonly accelerator: string | undefined;
    private readonly _actions;
    get actions(): readonly IAction[];
    constructor(id: number, label: string, actions: readonly IAction[], accelerator?: string, cssClass?: string);
    dispose(): void;
    run(): Promise<void>;
}
export declare class EmptySubmenuAction extends Action {
    static readonly ID = -201;
    constructor();
}
